"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Summary = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const format_1 = require("./../libs/format");
const logger_1 = require("./../libs/logger");
const events_manager_1 = require("./../managers/events-manager");
class Summary {
    logger;
    count = {
        init: 0,
        exec: 0,
        dispose: 0,
    };
    time = {
        init: 0,
        exec: 0,
        dispose: 0,
        execution: 0
    };
    constructor(logger) {
        this.logger = logger;
        events_manager_1.GlobalEvent
            .on('element/exec', () => {
            this.count.exec++;
        })
            .on('element/init', () => {
            this.count.init++;
        })
            .on('element/dispose', () => {
            this.count.dispose++;
        })
            .on('scene/init:before', () => {
            this.time.init = Date.now();
            this.time.execution = Date.now();
        })
            .on('scene/init:end', () => {
            this.time.init = Date.now() - this.time.init;
        })
            .on('scene/exec:before', () => {
            this.time.exec = Date.now();
        })
            .on('scene/exec:end', () => {
            this.time.exec = Date.now() - this.time.exec;
        })
            .on('scene/dispose:before', () => {
            this.time.dispose = Date.now();
        })
            .on('scene/dispose:end', () => {
            this.time.dispose = Date.now() - this.time.dispose;
        });
    }
    print() {
        if (!this.logger.is(logger_1.LoggerLevel.DEBUG))
            return;
        this.logger.log('');
        this.logger.log(ansi_colors_1.default.gray('»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»'));
        this.logger.log(`%s\t%s`, 'Runs    ', `${this.count.exec}(items)`);
        this.logger.log(`%s\t%s`, 'Duration', `${(0, format_1.formatDuration)(Date.now() - this.time.execution)}`);
        this.logger.log(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'initial', this.count.init, (0, format_1.formatDuration)(this.time.init));
        this.logger.log(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'execute', this.count.exec, (0, format_1.formatDuration)(this.time.exec));
        this.logger.log(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'dispose', this.count.dispose, (0, format_1.formatDuration)(this.time.dispose));
        this.logger.log(ansi_colors_1.default.gray('«««««««««««««««««««««««««««««««««««««««««««««««««««««««««««««««'));
    }
}
exports.Summary = Summary;
//# sourceMappingURL=summary.js.map