"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MDDoc = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const fs_1 = require("fs");
const promises_1 = require("fs/promises");
const path_1 = require("path");
const element_shadow_1 = require("../element-shadow");
const md_file_output_1 = require("./parser/md-file-output");
const md_file_parser_1 = require("./parser/md-file-parser");
class MDDoc extends element_shadow_1.ElementShadow {
    saveTo;
    includeDirs;
    excludeDirs;
    includePattern = /.+/;
    prependMDs;
    appendMDs;
    async init(props) {
        if (!Array.isArray(props.includeDirs))
            props.includeDirs = [props.includeDirs];
        if (!Array.isArray(props.excludeDirs))
            props.excludeDirs = [props.excludeDirs];
        if (props.includePattern)
            props.includePattern = new RegExp(props.includePattern);
        Object.assign(this, props);
    }
    async exec() {
        if (!this.includeDirs?.length || !this.saveTo)
            return;
        this.logger.debugBlock(true);
        this.includeDirs = this.includeDirs.map(dir => this.scene.getPath(dir));
        this.saveTo = this.scene.getPath(this.saveTo);
        const mdFileOutput = new md_file_output_1.MDFileOutput(this.title);
        await Promise.all(this.includeDirs.map(dirPath => this.scanDir(dirPath, mdFileOutput)));
        mdFileOutput.scanDone();
        const preContents = await Promise.all(this.prependMDs?.map(async (opt) => {
            if (typeof opt === 'string')
                return opt;
            const buf = await (0, promises_1.readFile)(this.scene.getPath(opt.path));
            return buf.toString('utf8');
        }) || []);
        mdFileOutput.prependContent(...preContents);
        const postContents = await Promise.all(this.appendMDs?.map(async (opt) => {
            if (typeof opt === 'string')
                return opt;
            const buf = await (0, promises_1.readFile)(this.scene.getPath(opt.path));
            return buf.toString('utf8');
        }) || []);
        mdFileOutput.appendContent(...postContents);
        mdFileOutput.save(this.saveTo);
        this.logger.debugBlock(false);
    }
    async scanDir(dirPath, mdFileOutput) {
        if (this.excludeDirs?.find(e => dirPath.includes(e)) || !this.includePattern?.test(dirPath))
            return;
        if ((0, fs_1.statSync)(dirPath).isFile()) {
            const isGot = await this.scanFile(dirPath, mdFileOutput);
            if (isGot) {
                this.logger.debug(`%s %s`, ansi_colors_1.default.green('✓'), ansi_colors_1.default.gray(dirPath));
            }
            else {
                this.logger.debug(`%s %s`, ansi_colors_1.default.red('✗'), ansi_colors_1.default.gray(dirPath));
            }
        }
        else {
            const items = await (0, promises_1.readdir)(dirPath);
            await Promise.all(items.map(itemPath => this.scanDir((0, path_1.join)(dirPath, itemPath), mdFileOutput)));
        }
    }
    async scanFile(filePath, mdFileOutput) {
        const mdFileParser = new md_file_parser_1.MDFileParser(filePath);
        const rs = await mdFileParser.analystic();
        mdFileOutput.addMDFileParser(mdFileParser);
        return !!rs.length;
    }
}
exports.MDDoc = MDDoc;
//# sourceMappingURL=md.js.map