"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyElementShadowPrototype = exports.ElementShadow = void 0;
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const async_function_1 = require("./../libs/async-function");
const logger_1 = require("./../libs/logger");
const variable_1 = require("./../libs/variable");
const IGNORE_EVAL_ELEMENT_SHADOW_PROPS = [
    '$$evalExps',
    '$$ignoreVarsBeforeExec',
    'ignore',
    'error',
    'vars',
    'loop',
    'loopKey',
    'loopValue',
    'if',
    'tag',
    'parent',
    'result',
    'logger',
    'scene',
    'rootScene',
];
class ElementShadow {
    $$evalExps = [];
    $$ignoreEvalProps = [];
    title;
    ignore;
    ignoreError;
    error;
    log;
    vars;
    async;
    loop;
    loopKey;
    loopValue;
    if;
    tag;
    parent;
    result;
    logger;
    scene;
    rootScene;
    getParentByClassName(ClazzType) {
        let parent = this.parent;
        do {
            if (parent instanceof ClazzType)
                return parent;
        } while (parent = parent['parent']);
        return parent;
    }
    async setVarsAfterExec() {
        if (this['vars']) {
            const keys = await this.scene.setVars(this.vars, this.result, this);
            if (!keys?.length)
                return;
            this.logger.trace(`[vars] \t%j`, keys.reduce((sum, e) => {
                sum[e] = this.scene.sceneVars[e];
                return sum;
            }, {}));
        }
    }
    async evalPropsBeforeExec() {
        await Promise.all(this.$$evalExps.map(async (key) => {
            this[key] = await this.scene.getVars(this[key], this);
        }));
    }
    $$getLoggerLevel() {
        return this.log || this.parent?.$$getLoggerLevel();
    }
    async $$prepare() {
        if (this.logger.is(logger_1.LoggerLevel.INFO) && this.parent?.title) {
            this.logger.addIndent();
        }
        if (this.if === undefined)
            return true;
        this.if = await this.scene.getVars(this.if, this);
        return !!this.if;
    }
    $$markElementNeedReplace() {
        const props = Object.keys(this);
        this.$$evalExps = props.filter(key => {
            return !IGNORE_EVAL_ELEMENT_SHADOW_PROPS.includes(key) &&
                !this.$$ignoreEvalProps?.includes(key) &&
                (0, variable_1.isGetEvalExp)(this[key]);
        });
    }
    $$extend(ids) {
        if (!ids?.length)
            return;
        if (typeof ids === 'string')
            ids = [ids];
        const props = {};
        ids.forEach(id => {
            const cached = this.rootScene.templatesManager.getFromCached(id);
            cached && (0, lodash_merge_1.default)(props, cached);
        });
        return props;
    }
    $$clone() {
        const newElement = (0, lodash_clonedeep_1.default)(this);
        return newElement;
    }
    $$export(id, props) {
        if (!id)
            return;
        this.rootScene.templatesManager.pushToCached(id, props);
        this.logger.trace(`->    \t%s`, id);
    }
    async callFunctionScript(script, ctx = this, others = {}) {
        const rs = await (0, async_function_1.callFunctionScript)(script, ctx, { vars: this.scene.sceneVars, logger: this.logger, globalVars: this.rootScene.globalVars, utils: this.rootScene.globalUtils, ...others });
        return rs;
    }
    init(_props) { }
    dispose() { }
}
exports.ElementShadow = ElementShadow;
const ownerProperties = Object.getOwnPropertyNames(ElementShadow.prototype).filter(k => !['constructor', 'init', 'exec', 'dispose'].includes(k));
function copyElementShadowPrototype(elem) {
    if (elem.$$clone)
        return;
    if (!elem.$$ignoreEvalProps)
        elem.$$ignoreEvalProps = [];
    ownerProperties.forEach(k => {
        if (!elem[k])
            elem[k] = ElementShadow.prototype[k];
    });
}
exports.copyElementShadowPrototype = copyElementShadowPrototype;
//# sourceMappingURL=element-shadow.js.map