"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_temp_1 = require("../../libs/file-temp");
const testing_1 = require("../../testing");
const exec_js_1 = require("./exec-js");
let execJs;
beforeEach(() => {
    testing_1.Testing.reset();
    execJs = testing_1.Testing.newElement(exec_js_1.ExecJs);
});
afterAll(async () => {
    await execJs.dispose();
});
test('should be executed', async () => {
    const txt = 'hello world';
    await execJs.init({
        title: 'Test function',
        script: `return '${txt}'`
    });
    const msg = await execJs.exec();
    expect(msg).toBe(txt);
});
test('should get value directly from global vars', async () => {
    testing_1.Testing.vars.txt = 'hello world';
    await execJs.init(`logger.info('Test here'); return vars.txt`);
    const msg = await execJs.exec();
    expect(msg).toBe(testing_1.Testing.vars.txt);
});
test('should not get expression value from global vars', async () => {
    testing_1.Testing.vars.txt = 'hello world';
    await execJs.init(`return "\${vars.txt}"`);
    const msg = await execJs.exec();
    expect(msg).toBe('${vars.txt}');
});
test('should run from external file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.execJs');
    await tmpFile.create(`logger.info('Test here'); return vars.txt`);
    try {
        testing_1.Testing.vars.txt = 'hello world';
        await execJs.init({ path: tmpFile.file });
        const msg = await execJs.exec();
        expect(msg).toBe(testing_1.Testing.vars.txt);
    }
    finally {
        tmpFile.remove();
    }
});
//# sourceMappingURL=exec-js.spec.js.map