"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Group = void 0;
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const element_shadow_1 = require("../element-shadow");
class Group extends element_shadow_1.ElementShadow {
    $$ignoreEvalProps = ['runs', 'asyncJobs'];
    runs = [];
    asyncJobs = [];
    async init(props) {
        if (Array.isArray(props)) {
            this.runs = props;
        }
        else {
            Object.assign(this, props);
        }
        this.runs = this.runs?.filter(e => e) || [];
        this.asyncJobs = [];
    }
    async exec(input) {
        const runs = new Array();
        for (const _e of this.runs) {
            const e = typeof _e === 'string' ? { 'echo': { content: _e } } : _e;
            const name = Object.keys(e)[0];
            const props = (0, lodash_clonedeep_1.default)(e[name]);
            const ElemClass = await this.rootScene.tagsManager.loadElementClass(name, this.scene);
            const elem = this.scene.elementBuilder
                .element(ElemClass)
                .tag(name)
                .parent(this)
                .logger(this.logger)
                .build();
            await elem.init(props);
            if (elem.ignore)
                continue;
            const loop = elem.loop;
            if (loop === undefined) {
                if (this.asyncJobs.length && !elem.async) {
                    await Promise.all(this.asyncJobs);
                    this.asyncJobs.splice(0, this.asyncJobs.length);
                }
                const isRun = await this.execElement(elem, input);
                isRun && runs.push(elem);
            }
            else {
                let loopCondition = await this.scene.getVars(loop, this);
                if (loopCondition) {
                    if (Array.isArray(loopCondition)) {
                        for (let i = 0; i < loopCondition.length; i++) {
                            const newElem = await elem.$$clone();
                            newElem.loopKey = i;
                            newElem.loopValue = loopCondition[newElem.loopKey];
                            const isRun = await this.execElement(newElem, input);
                            isRun && runs.push(newElem);
                        }
                    }
                    else if (typeof loopCondition === 'object') {
                        for (const key in loopCondition) {
                            const newElem = await elem.$$clone();
                            newElem.loopKey = key;
                            newElem.loopValue = loopCondition[newElem.loopKey];
                            const isRun = await this.execElement(newElem, input);
                            isRun && runs.push(newElem);
                        }
                    }
                    else if (loopCondition === true) {
                        while (loopCondition) {
                            const newElem = await elem.$$clone();
                            newElem.loopValue = loopCondition;
                            const isRun = await this.execElement(newElem, input);
                            isRun && runs.push(newElem);
                            loopCondition = await this.scene.getVars(loop, this);
                        }
                    }
                }
            }
        }
        if (this.asyncJobs.length) {
            await Promise.all(this.asyncJobs);
            this.asyncJobs.splice(0, this.asyncJobs.length);
        }
        return runs;
    }
    async execElement(elem, input) {
        const isContinue = await elem.$$prepare();
        if (!isContinue)
            return false;
        const p = new Promise(async (resolve, reject) => {
            try {
                await elem.exec(input);
                resolve(undefined);
            }
            catch (err) {
                reject(err);
            }
            finally {
                await elem.dispose();
            }
        });
        if (!elem.async) {
            await p;
        }
        else {
            this.asyncJobs.push(p);
        }
        return true;
    }
}
exports.Group = Group;
//# sourceMappingURL=group.js.map