"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Post = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const fs_1 = require("fs");
const get_1 = require("./get");
class Post extends get_1.Get {
    method = 'post';
    type = 'json';
    body;
    async send(fetchOpts = {}) {
        if (this.saveTo) {
            this.responseType = 'pipe';
            this.saveTo = this.scene.getPath(this.saveTo);
        }
        const body = this.getRequestBody();
        this.prehandleHeaders();
        const rs = await fetch(this.fullURLQuery, {
            method: this.method,
            headers: this.headers,
            body,
            ...fetchOpts
        });
        const data = await this.getResponseData(rs);
        this.response = {
            ok: rs.ok,
            headers: this.getResponseHeader(rs),
            data,
            status: rs.status,
            statusText: rs.statusText,
        };
        return this.response;
    }
    getRequestBody() {
        if (this.body === null || this.body === undefined)
            return this.body;
        this.logger.debug(`%s\t%j`, ansi_colors_1.default.gray('‣ Body   '), this.body);
        switch (this.type) {
            case 'multipart':
                const form1 = new FormData();
                Object.keys(this.body).forEach(key => {
                    const vl = this.body[key];
                    if (typeof vl === 'object') {
                        const { path, name } = vl;
                        form1.append(key, new Blob([(0, fs_1.readFileSync)(this.scene.getPath(path))]), name);
                    }
                    else {
                        form1.append(key, vl);
                    }
                });
                return form1;
            case 'form':
                this.setHeader('content-type', 'application/x-www-form-urlencoded');
                const form2 = new URLSearchParams();
                Object.keys(this.body).forEach(key => form2.append(key, this.body[key]));
                return form2;
            case 'text':
                this.setHeader('content-type', 'text/plain');
                return this.body.toString();
            case 'json':
                this.setHeader('content-type', 'application/json');
                return JSON.stringify(this.body);
            default:
                return this.body;
        }
    }
}
exports.Post = Post;
//# sourceMappingURL=post.js.map