"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Install = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const modules_manager_1 = require("../../managers/modules-manager");
const packages_manager_1 = require("../../managers/packages-manager");
const element_shadow_1 = require("../element-shadow");
class Install extends element_shadow_1.ElementShadow {
    packages = {};
    async init(eprops) {
        let _packages;
        if (Array.isArray(eprops)) {
            _packages = eprops;
        }
        else if (typeof eprops === 'string') {
            _packages = eprops.split(',').map(e => e.trim().split(' ').map(e => e.trim())).flat().filter(e => e);
        }
        else {
            const { packages, ...props } = eprops;
            _packages = packages;
            Object.assign(this, props);
        }
        _packages?.forEach((pack) => {
            if (typeof pack === 'string') {
                this.packages[pack] = pack;
            }
            else if (typeof pack === 'object') {
                const [name] = Object.keys(pack);
                this.packages[name] = pack[name];
            }
        });
    }
    async exec() {
        const packs = Object.keys(this.packages || {});
        if (!packs.length)
            throw new Error('Packages are required to install');
        const packsInstall = packs.reduce((sum, name) => {
            if (!(0, fs_1.existsSync)((0, path_1.join)(modules_manager_1.nodeModulesDir, name))) {
                if (name !== this.packages[name]) {
                    sum.push(`${name}@${this.packages[name]}`);
                }
                else {
                    sum.push(`${name}`);
                }
            }
            return sum;
        }, []);
        if (!packsInstall.length)
            return false;
        const logger = this.logger.clone();
        if (this.title)
            logger.addIndent();
        const packageManager = new packages_manager_1.PackagesManager(this.scene);
        await packageManager.install(...packsInstall);
        return true;
    }
}
exports.Install = Install;
//# sourceMappingURL=install.js.map