"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RootScene = void 0;
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const scene_1 = require("./../components/scene/scene");
const events_manager_1 = require("./../managers/events-manager");
const tags_manager_1 = require("./../managers/tags-manager");
const templates_manager_1 = require("./../managers/templates-manager");
const utility_function_manager_1 = require("./../managers/utility-function-manager");
class RootScene extends scene_1.Scene {
    logger;
    tagsManager = new tags_manager_1.TagsManager(this);
    templatesManager = new templates_manager_1.TemplatesManager();
    globalUtils = new utility_function_manager_1.UtilityFunctionManager();
    globalVars = {};
    rootDir = '';
    constructor(logger) {
        super(true);
        this.logger = logger;
        this.$$ignoreEvalProps.push('globalVars', 'globalUtils', 'tagsManager', 'templatesManager', 'rootDir');
        this.log = logger.levelName;
        this.scene = this.rootScene = this;
    }
    async exec() {
        events_manager_1.GlobalEvent.emit('scene/exec:before');
        try {
            const rs = await super.exec();
            return rs;
        }
        finally {
            events_manager_1.GlobalEvent.emit('scene/exec:end');
        }
    }
    async dispose() {
        events_manager_1.GlobalEvent.emit('scene/dispose:before');
        try {
            await super.dispose();
        }
        finally {
            events_manager_1.GlobalEvent.emit('scene/dispose:end');
        }
    }
    async init(props) {
        events_manager_1.GlobalEvent.emit('scene/init:before');
        try {
            await super.init(props);
        }
        finally {
            events_manager_1.GlobalEvent.emit('scene/init:end');
        }
    }
    mergeGlobalVars(obj) {
        (0, lodash_merge_1.default)(this.globalVars, obj);
    }
}
exports.RootScene = RootScene;
//# sourceMappingURL=root-scene.js.map