"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const test_1 = require("./test");
let testElem;
beforeEach(() => {
    testing_1.Testing.reset();
    testElem = testing_1.Testing.newElement(test_1.Test);
});
afterEach(async () => {
    await testElem.dispose();
});
test('quick test without title', async () => {
    testing_1.Testing.vars.i = 11;
    await testElem.init('${vars.i >= 10}');
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('test script without title', async () => {
    testing_1.Testing.vars.i = 9;
    await testElem.init({
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe('');
});
test('quick test', async () => {
    testing_1.Testing.vars.i = 11;
    await testElem.init({
        title: 'Greater than 10',
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('test with a script', async () => {
    testing_1.Testing.vars.i = 11;
    await testElem.init({
        title: 'Greater than 10',
        script: "vars.i >= 10"
    });
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('quick test failed', async () => {
    testing_1.Testing.vars.i = 9;
    await testElem.init({
        title: 'Greater than 10',
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe('');
});
test('test with a script failed then print error detail', async () => {
    testing_1.Testing.vars.i = 9;
    const mes = 'i is less than 10';
    await testElem.init({
        title: 'Greater than 10',
        script: `if (vars.i < 10) this.failed('${mes}')`
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe(mes);
});
//# sourceMappingURL=test.spec.js.map