"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const vars_1 = require("./vars");
let vars;
beforeEach(() => {
    testing_1.Testing.reset();
    vars = testing_1.Testing.newElement(vars_1.Vars);
});
afterEach(async () => {
    await vars.dispose();
});
test('should set to scene vars', async () => {
    try {
        await vars.init({
            string: 'foo',
            number: 1,
            boolean: true,
            object: {
                string: 'foo',
                number: 1,
                boolean: true,
            },
            array1: [1, '2', true],
            array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true,
                }]
        });
        expect(testing_1.Testing.globalVars.String).toBeUndefined();
        expect(testing_1.Testing.globalVars.Number).toBeUndefined();
        expect(testing_1.Testing.globalVars.Boolean).toBeUndefined();
        expect(testing_1.Testing.globalVars.Object).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array1).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array2).toBeUndefined();
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
        await vars.exec();
        expect(testing_1.Testing.vars.string).toBe('foo');
        expect(testing_1.Testing.vars.number).toBe(1);
        expect(testing_1.Testing.vars.boolean).toBe(true);
        expect(testing_1.Testing.vars.object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true,
        });
        expect(testing_1.Testing.vars.array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.vars.array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true,
            }]);
        expect(testing_1.Testing.globalVars.String).toBeUndefined();
        expect(testing_1.Testing.globalVars.Number).toBeUndefined();
        expect(testing_1.Testing.globalVars.Boolean).toBeUndefined();
        expect(testing_1.Testing.globalVars.Object).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array1).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array2).toBeUndefined();
    }
    finally {
        await vars.dispose();
    }
});
test('should set to global vars', async () => {
    try {
        await vars.init({
            String: 'foo',
            Number: 1,
            Boolean: true,
            Object: {
                string: 'foo',
                number: 1,
                boolean: true,
            },
            Array1: [1, '2', true],
            Array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true,
                }]
        });
        expect(testing_1.Testing.globalVars.String).toBeUndefined();
        expect(testing_1.Testing.globalVars.Number).toBeUndefined();
        expect(testing_1.Testing.globalVars.Boolean).toBeUndefined();
        expect(testing_1.Testing.globalVars.Object).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array1).toBeUndefined();
        expect(testing_1.Testing.globalVars.Array2).toBeUndefined();
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
        await vars.exec();
        expect(testing_1.Testing.globalVars.String).toBe('foo');
        expect(testing_1.Testing.globalVars.Number).toBe(1);
        expect(testing_1.Testing.globalVars.Boolean).toBe(true);
        expect(testing_1.Testing.globalVars.Object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true,
        });
        expect(testing_1.Testing.globalVars.Array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.globalVars.Array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true,
            }]);
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
    }
    finally {
        await vars.dispose();
    }
});
test('should eval value into vars', async () => {
    await vars.init({
        name: 'scene name',
        Name: 'global name'
    });
    await vars.exec();
    const test = testing_1.Testing.newElement(vars_1.Vars);
    await test.init({
        Hello: 'Hello ${vars.Name}',
        hello: 'hello ${vars.name}'
    });
    await test.exec();
    await test.dispose();
    expect(testing_1.Testing.vars.hello).toBe('hello scene name');
    expect(testing_1.Testing.globalVars.Hello).toBe('Hello global name');
    expect(testing_1.Testing.vars.Hello).toBeUndefined();
    expect(testing_1.Testing.globalVars.hello).toBeUndefined();
});
//# sourceMappingURL=vars.spec.js.map