"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileRemote = void 0;
const fs_1 = require("fs");
const promises_1 = require("fs/promises");
class FileRemote {
    uri;
    get isRemote() {
        return (this.uri.startsWith('http://') || this.uri.startsWith('https://')) ? true : false;
    }
    constructor(uri, scene) {
        this.uri = uri;
        if (!uri)
            throw new Error(`File is required`);
        if (!this.isRemote) {
            this.uri = scene.getPath(this.uri);
        }
    }
    get existed() {
        if (this.isRemote)
            return undefined;
        return (0, fs_1.existsSync)(this.uri);
    }
    async getContent() {
        if (!this.isRemote) {
            const buf = await (0, promises_1.readFile)(this.uri);
            return buf;
        }
        const rs = await fetch(this.uri);
        const ab = await rs.arrayBuffer();
        return Buffer.from(new Uint8Array(ab));
    }
    async getTextContent() {
        if (!this.isRemote) {
            const buf = await (0, promises_1.readFile)(this.uri);
            return buf.toString();
        }
        const rs = await fetch(this.uri);
        const txt = await rs.text();
        return txt;
    }
}
exports.FileRemote = FileRemote;
//# sourceMappingURL=file-remote.js.map