"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jest_mock_server_1 = require("jest-mock-server");
const testing_1 = require("./../testing");
const file_remote_1 = require("./file-remote");
const file_temp_1 = require("./file-temp");
it('should get content if input is a file', async () => {
    const tempFile = new file_temp_1.FileTemp();
    try {
        await tempFile.create('ok');
        const f = new file_remote_1.FileRemote(tempFile.file, testing_1.Testing.rootScene);
        expect(f.isRemote).toBe(false);
        expect(f.existed).toBe(true);
        expect((await f.getContent()).toString()).toBe('ok');
        expect(await f.getTextContent()).toBe('ok');
    }
    finally {
        tempFile.remove();
    }
});
it('should get content if input is a url', async () => {
    const server = new jest_mock_server_1.MockServer();
    server.get('/')
        .mockImplementation((ctx) => {
        ctx.status = 201;
        ctx.body = 'ok';
    });
    try {
        await server.start();
        const f = new file_remote_1.FileRemote(server.getURL().toString(), testing_1.Testing.rootScene);
        expect(f.isRemote).toBe(true);
        expect(f.existed).toBeUndefined();
        expect((await f.getContent()).toString()).toBe('ok');
        expect(await f.getTextContent()).toBe('ok');
    }
    finally {
        await server.stop();
    }
});
//# sourceMappingURL=file-remote.spec.js.map