"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgressBar = void 0;
const modules_manager_1 = require("./../managers/modules-manager");
class ProgressBar {
    logger;
    color;
    static Color = {
        Black: 'black',
        Red: 'red',
        Green: 'green',
        Yellow: 'yellow',
        Blue: 'blue',
        Magenta: 'magenta',
        Cyan: 'cyan',
        White: 'white',
        Gray: 'gray',
    };
    spinner;
    constructor(logger, color = ProgressBar.Color.Cyan) {
        this.logger = logger;
        this.color = color;
    }
    async init(txt) {
        const { default: ora } = await (0, modules_manager_1.loadESModule)('ora');
        this.spinner = ora({
            spinner: {
                interval: 120,
                frames: "-\\|/".split('')
            },
            color: this.color,
            text: txt,
            indent: this.logger.indent * 2
        });
    }
    start(txt) {
        return this.spinner?.start(txt);
    }
    update(txt, level) {
        if (this.spinner)
            this.spinner.text = this.logger.formatWithoutIndent(txt, level);
    }
    stop() {
        if (this.spinner)
            this.spinner.indent = 0;
        return this.spinner?.stop();
    }
    passed(txt) {
        return this.spinner?.succeed(txt);
    }
    failed(txt) {
        return this.spinner?.fail(txt);
    }
}
exports.ProgressBar = ProgressBar;
//# sourceMappingURL=progress-bar.js.map