"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetEvalExp = exports.getVars = exports.setVars = void 0;
const async_function_1 = require("./../libs/async-function");
const vars_1 = require("./vars");
async function setVars(varObj, vl, ctx, { sceneVars, globalVars, ...others }) {
    if (!varObj)
        return;
    const v = new vars_1.Vars(sceneVars, globalVars);
    if (typeof varObj === 'string') {
        v.set({ [varObj]: vl });
        return [varObj];
    }
    const keys = Object.keys(varObj);
    const newVars = {};
    const otherVars = { vars: { ...sceneVars, ...globalVars }, ...others };
    for (const k of keys) {
        newVars[k] = await getVars(varObj[k], ctx, otherVars);
    }
    v.set(newVars);
    return keys;
}
exports.setVars = setVars;
async function getVars(str, ctx, others) {
    if (str) {
        const evalExp = isGetEvalExp(str);
        switch (evalExp) {
            case String:
                str = `\`${str}\``;
                if (str[1] === '$' && str[str.length - 2] === '}') {
                    str = str.replace(/^`\$\{([^\}]+)\}`$/, '$1');
                }
                let vl = await (0, async_function_1.callFunctionScript)(`return ${str}`, ctx, others);
                if (typeof vl === 'string' && vl.indexOf('${') !== -1) {
                    vl = await getVars(vl, ctx, others);
                }
                return vl;
            case Object:
                const obj = await evalObject(str, ctx, others);
                return obj;
        }
    }
    return str;
}
exports.getVars = getVars;
function isGetEvalExp(vl) {
    if (!vl)
        return null;
    if (typeof vl === 'string') {
        if (vl.includes('${'))
            return String;
    }
    else if (typeof vl === 'object') {
        if (isGetEvalExp(JSON.stringify(vl)))
            return Object;
    }
    return null;
}
exports.isGetEvalExp = isGetEvalExp;
async function evalObject(obj, ctx, others) {
    if (Array.isArray(obj)) {
        const vl = await Promise.all(obj.map(o => getVars(o, ctx, others)));
        return vl;
    }
    for (const k of Object.keys(obj)) {
        obj[k] = await getVars(obj[k], ctx, others);
    }
    return obj;
}
//# sourceMappingURL=variable.js.map