"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PackagesManager = void 0;
const child_process_1 = require("child_process");
const path_1 = require("path");
const exec_1 = require("./../components/exec/exec");
const logger_1 = require("./../libs/logger");
const progress_bar_1 = require("./../libs/progress-bar");
const modules_manager_1 = require("./modules-manager");
class PackagesManager {
    scene;
    bin;
    logger;
    tag = 'package-manager';
    get cmdInstall() {
        return this.bin === 'npm' ?
            ['npm', 'install', '--no-package-lock', '--save-optional', '--prefix', `${(0, path_1.join)(modules_manager_1.nodeModulesDir, '..')}`] :
            ['yarn', 'add', '--no-lockfile', '--optional', '--modules-folder', `${modules_manager_1.nodeModulesDir}`];
    }
    constructor(scene) {
        this.scene = scene;
        this.logger = this.scene.logger.clone(this.tag);
        let log = (0, child_process_1.execSync)('yarn -v').toString();
        if (!log) {
            log = (0, child_process_1.execSync)('npm -v').toString();
            if (!log)
                throw new Error('Not installed npm or yarn yet');
            this.bin = 'npm';
        }
        else {
            this.bin = 'yarn';
        }
    }
    async install(...packages) {
        const cmd = [...this.cmdInstall, ...packages];
        const msg = `tags ${packages.map(e => `"${e}"`).join(', ')}`;
        const bar = !this.logger.is(logger_1.LoggerLevel.TRACE) ? new progress_bar_1.ProgressBar(this.logger) : undefined;
        try {
            if (bar) {
                await bar.init(`Installing ${msg}`);
                bar.start();
            }
            else {
                this.logger.debug(`Installing ${msg}`);
            }
            const exec = this.scene.elementBuilder
                .element(exec_1.Exec)
                .tag(this.tag)
                .logger(this.logger)
                .build();
            await exec.init({
                commands: cmd
            });
            await exec.exec();
            if (bar) {
                bar.passed(`Installed ${msg} successfully`);
            }
            else {
                this.logger.info(`Installed ${msg} successfully`);
            }
        }
        catch (err) {
            if (bar) {
                bar.failed(`Installed ${msg} failed`);
            }
            else {
                this.logger.error(`Installed ${msg} failed`);
            }
            throw err;
        }
    }
}
exports.PackagesManager = PackagesManager;
//# sourceMappingURL=packages-manager.js.map