"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_temp_1 = require("./../libs/file-temp");
const testing_1 = require("./../testing");
beforeEach(() => {
    testing_1.Testing.reset();
});
afterEach(async () => {
});
test('load a new tag from a class in a external file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.js');
    try {
        await tmpFile.create(`
    module.exports = class {
      init(props) {
        this.props = props
      }
      exec() {
        return this.props
      }
      dispose() { }
    }`);
        const data = { say: 'hello test' };
        await testing_1.Testing.rootScene.tagsManager.register({
            test1: tmpFile.file,
        });
        const TestClass = await testing_1.Testing.rootScene.tagsManager.loadElementClass('test1', testing_1.Testing.rootScene);
        const test = testing_1.Testing.newElement(TestClass);
        await test.init(data);
        const rs = await test.exec();
        expect(rs).toEqual(data);
    }
    finally {
        tmpFile.remove();
    }
});
test('load a new tag from a object in a external file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.js');
    try {
        await tmpFile.create(`
    module.exports = {
      init(props) {
        this.props = props
      },
      exec() {
        return this.props
      }
    }`);
        const data = { say: 'hello test' };
        await testing_1.Testing.rootScene.tagsManager.register({
            test1: tmpFile.file,
        });
        const TestClass = await testing_1.Testing.rootScene.tagsManager.loadElementClass('test1', testing_1.Testing.rootScene);
        const test = testing_1.Testing.newElement(TestClass);
        await test.init(data);
        const rs = await test.exec();
        expect(rs).toEqual(data);
    }
    finally {
        tmpFile.remove();
    }
});
//# sourceMappingURL=tags-manager.spec.js.map